@@ -1,16 +1,10 @@
 use crossterm::event::Event;
 use irust_api::{Command, GlobalVariables};
 
-use self::{
-    script1::ScriptManager, script2::ScriptManager2, script3::ScriptManager3,
-    script4::ScriptManager4,
-};
+use self::script4::ScriptManager4;
 
 use super::options::Options;
 
-pub mod script1;
-pub mod script2;
-pub mod script3;
 pub mod script4;
 
 pub trait Script {
@@ -139,14 +133,8 @@ impl super::IRust {
     ///////////
     ///
     pub fn choose_script_mg(options: &Options) -> Option<Box<dyn Script>> {
-        if options.activate_scripting4 {
+        if options.activate_scripting {
             ScriptManager4::new().map(|script_mg| Box::new(script_mg) as Box<dyn Script>)
-        } else if options.activate_scripting3 {
-            ScriptManager3::new().map(|script_mg| Box::new(script_mg) as Box<dyn Script>)
-        } else if options.activate_scripting2 {
-            Some(Box::new(ScriptManager2::new()) as Box<dyn Script>)
-        } else if options.activate_scripting {
-            ScriptManager::new().map(|script_mg| Box::new(script_mg) as Box<dyn Script>)
         } else {
             None
         }
